# -*- coding: utf-8 -*-
"""
Created on Tue Aug 25 08:42:31 2019

@author: Riccardo Busti, Niccolò Tubini
@license: creative commons 4.0
"""

import os
import pandas as pd
import numpy as np
import matplotlib
import math

def sum(a,b):
    return a+b

def minus(a,b):
    return a-b

def pro(a,b):
    return a*b

def div(a,b):
    return a/b

# versione 0.0.3
def sumabc(a,b,c):
    return a+b+c



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
                 name="asgara", # Replace with your own username
                 version="0.0.4",
                 author="Author",
                 author_email="author@example.com",
                 description="A small example package",
                 long_description=long_description,
                 long_description_content_type="text/markdown",
                 url="https://github.com/pypa/sampleproject",
                 packages=setuptools.find_packages(),
                 classifiers=[
                              "Programming Language :: Python :: 3",
                              "License :: OSI Approved :: MIT License",
                              "Operating System :: OS Independent",
                              ],
                 python_requires='>=3.6',
                 )
